package com.example.shawarma.screens

import android.annotation.SuppressLint
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material.Scaffold
import androidx.compose.material.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.ui.Modifier
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.currentBackStackEntryAsState
import androidx.navigation.compose.rememberNavController
import com.example.shawarma.screens.authorization.AuthorizationScreen
import com.example.shawarma.screens.cart.CartScreen
import com.example.shawarma.screens.discount.DiscountScreen
import com.example.shawarma.screens.home.HomeScreen
import com.example.shawarma.screens.registration.RegistrationScreen
import com.example.shawarma.ui.theme.MyLightYellow
import com.example.shawarma.utils.ScreenPaths
import com.example.shawarma.widgets.BottomNavBar

@SuppressLint("UnusedMaterialScaffoldPaddingParameter")
@Composable
fun MainNavBar() {
    val navController = rememberNavController()
    Scaffold(
        backgroundColor = MyLightYellow,
        modifier = Modifier.fillMaxSize(),
        bottomBar = {
            val navBackStackEntry by navController.currentBackStackEntryAsState()
            val currentRoute = navBackStackEntry?.destination?.route
            if ( currentRoute != ScreenPaths.authorization.name && currentRoute != ScreenPaths.registration.name) {
                BottomNavBar(navController = navController)
            }
        }
    ) {scaffoldPadding ->
        NavHost(navController = navController, startDestination = ScreenPaths.authorization.name) {
            composable(ScreenPaths.authorization.name) {
                AuthorizationScreen(navController)
            }
            composable(ScreenPaths.registration.name) {
                RegistrationScreen(navController)
            }
            composable(ScreenPaths.home.name) {
                HomeScreen()
            }
            composable(ScreenPaths.discount.name) {
                DiscountScreen()
            }
            composable(ScreenPaths.cart.name) {
                CartScreen()
            }
        }
    }
}